# This is an auto-generated Django model module.
# You'll have to do the following manually to clean this up:
#   * Rearrange models' order
#   * Make sure each model has one field with primary_key=True
#   * Make sure each ForeignKey and OneToOneField has `on_delete` set to the desired behavior
#   * Remove `managed = False` lines if you wish to allow Django to create, modify, and delete the table
# Feel free to rename the models, but don't rename db_table values or field names.
from django.db import models


class Events(models.Model):
    id = models.PositiveIntegerField(primary_key=True)
    ra = models.FloatField()
    decl = models.FloatField()
    ra_original = models.FloatField()
    decl_original = models.FloatField()
    date_inserted = models.DateTimeField()
    date_updated = models.DateTimeField(blank=True, null=True)
    year = models.PositiveSmallIntegerField()
    base26suffix = models.CharField(max_length=20)
    htm16id = models.BigIntegerField(db_column='htm16ID')  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'events'
        unique_together = (('year', 'base26suffix'),)


class Akas(models.Model):
    id = models.AutoField(primary_key=True)
    event_id = models.ForeignKey(Events, to_field='id', db_column='event_id', on_delete = models.CASCADE)
    object_id = models.BigIntegerField()
    aka = models.CharField(max_length=30, blank=True, null=True)
    ra = models.FloatField()
    decl = models.FloatField()
    survey_database = models.CharField(max_length=50)
    user_id = models.CharField(max_length=50)
    source_ip = models.CharField(max_length=20, blank=True, null=True)
    original_flag_date = models.DateField()
    date_inserted = models.DateTimeField()
    htm16id = models.BigIntegerField(db_column='htm16ID')  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'akas'
        unique_together = (('object_id', 'survey_database'),)



class AbstractYear(models.Model):
    id = models.AutoField(primary_key=True)
    object_id = models.BigIntegerField()
    ra = models.FloatField()
    decl = models.FloatField()
    survey_database = models.CharField(max_length=50)
    user_id = models.CharField(max_length=50)
    source_ip = models.CharField(max_length=20, blank=True, null=True)
    date_inserted = models.DateTimeField()
    htm16id = models.BigIntegerField(db_column='htm16ID')  # Field name made lowercase.

    class Meta:
        abstract = True


class Y2013(AbstractYear):

    class Meta:
        managed = False
        db_table = 'y2013'
        unique_together = (('object_id', 'survey_database'),)

class Y2014(AbstractYear):

    class Meta:
        managed = False
        db_table = 'y2014'
        unique_together = (('object_id', 'survey_database'),)

class Y2015(AbstractYear):

    class Meta:
        managed = False
        db_table = 'y2015'
        unique_together = (('object_id', 'survey_database'),)

class Y2016(AbstractYear):

    class Meta:
        managed = False
        db_table = 'y2016'
        unique_together = (('object_id', 'survey_database'),)

class Y2017(AbstractYear):

    class Meta:
        managed = False
        db_table = 'y2017'
        unique_together = (('object_id', 'survey_database'),)

class Y2018(AbstractYear):

    class Meta:
        managed = False
        db_table = 'y2018'
        unique_together = (('object_id', 'survey_database'),)

class Y2019(AbstractYear):

    class Meta:
        managed = False
        db_table = 'y2019'
        unique_together = (('object_id', 'survey_database'),)

class Y2020(AbstractYear):

    class Meta:
        managed = False
        db_table = 'y2020'
        unique_together = (('object_id', 'survey_database'),)

class Y2021(AbstractYear):

    class Meta:
        managed = False
        db_table = 'y2021'
        unique_together = (('object_id', 'survey_database'),)

class Y2022(AbstractYear):

    class Meta:
        managed = False
        db_table = 'y2022'
        unique_together = (('object_id', 'survey_database'),)

class Y2023(AbstractYear):

    class Meta:
        managed = False
        db_table = 'y2023'
        unique_together = (('object_id', 'survey_database'),)

class Y2024(AbstractYear):

    class Meta:
        managed = False
        db_table = 'y2024'
        unique_together = (('object_id', 'survey_database'),)

class Y2025(AbstractYear):

    class Meta:
        managed = False
        db_table = 'y2025'
        unique_together = (('object_id', 'survey_database'),)

class Y2026(AbstractYear):

    class Meta:
        managed = False
        db_table = 'y2026'
        unique_together = (('object_id', 'survey_database'),)

class Y2027(AbstractYear):

    class Meta:
        managed = False
        db_table = 'y2027'
        unique_together = (('object_id', 'survey_database'),)

class Y2028(AbstractYear):

    class Meta:
        managed = False
        db_table = 'y2028'
        unique_together = (('object_id', 'survey_database'),)

class Y2029(AbstractYear):

    class Meta:
        managed = False
        db_table = 'y2029'
        unique_together = (('object_id', 'survey_database'),)

class Y2030(AbstractYear):

    class Meta:
        managed = False
        db_table = 'y2030'
        unique_together = (('object_id', 'survey_database'),)





# Generated by Django 3.2.5 on 2022-12-28 17:21

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('nameserverapi', '0001_initial'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Akas',
        ),
        migrations.DeleteModel(
            name='Events',
        ),
        migrations.DeleteModel(
            name='Y2016',
        ),
        migrations.DeleteModel(
            name='Y2017',
        ),
        migrations.DeleteModel(
            name='Y2018',
        ),
        migrations.DeleteModel(
            name='Y2019',
        ),
        migrations.DeleteModel(
            name='Y2020',
        ),
        migrations.DeleteModel(
            name='Y2021',
        ),
        migrations.DeleteModel(
            name='Y2022',
        ),
        migrations.DeleteModel(
            name='Y2023',
        ),
        migrations.DeleteModel(
            name='Y2024',
        ),
        migrations.DeleteModel(
            name='Y2025',
        ),
        migrations.DeleteModel(
            name='Y2026',
        ),
        migrations.DeleteModel(
            name='Y2027',
        ),
        migrations.DeleteModel(
            name='Y2028',
        ),
        migrations.DeleteModel(
            name='Y2029',
        ),
        migrations.DeleteModel(
            name='Y2030',
        ),
    ]



from django.urls import include, path
from rest_framework import routers
from . import views

router = routers.DefaultRouter()
router.register(r'eventsapi', views.EventsViewSet)

# For my generic serializer, I had to set basename to something.
#router.register(r'eventapi', views.EventView, basename = "event")

# Wire up our API using automatic URL routing.
# Additionally, we include login URLs for the browsable API.
urlpatterns = [
    path('', include(router.urls)),
    path('eventapi/', views.EventView.as_view()),
    path('api-auth/', include('rest_framework.urls', namespace='rest_framework'))
]



from django.shortcuts import get_object_or_404, render
from gkhtm._gkhtm import htmID
from gkutils.commonutils import coneSearchHTM, FULL, CAT_ID_RA_DEC_COLS, base26, Struct

from .models import *
from django import forms

from django_tables2 import RequestConfig
from django_tables2.utils import A  # alias for Accessor
import django_tables2 as tables2
from datetime import datetime
from django.db import IntegrityError

RADIUS = 3.0 # arcsec
MULTIPLIER = 10000000

# I can't believe that this works! The events table is not part of my long list,
# but we can add it here.
CAT_ID_RA_DEC_COLS['events'] = [['id', 'ra', 'decl'],1017]

# 2021-12-27 KWS Added years 2013 to 2015 for Pan-STARRS.
years = {2013: Y2013,
         2014: Y2014,
         2015: Y2015,
         2016: Y2016,
         2017: Y2017,
         2018: Y2018,
         2019: Y2019,
         2020: Y2020,
         2021: Y2021,
         2022: Y2022,
         2023: Y2023,
         2024: Y2024,
         2025: Y2025,
         2026: Y2026,
         2027: Y2027,
         2028: Y2028,
         2029: Y2029,
         2030: Y2030,
        }


class EventsTable(tables2.Table):
    id = tables2.Column()
    ra = tables2.Column()
    dec = tables2.Column()
    class Meta:
        model = Events
        exclude = []




class AddEventForm(forms.Form):
    internalObjectId = forms.IntegerField(required=True, widget=forms.TextInput(attrs={'size':'20'}))
    internalName = forms.CharField(widget=forms.TextInput(attrs={'size':'20'}))
    ra = forms.FloatField(required=True)
    decl = forms.FloatField(required=True)

    flagDate = forms.DateField(required=False, widget = forms.SelectDateWidget(years=range(2016, 2030)))
    userId = forms.CharField(required=True, widget=forms.TextInput(attrs={'size':'20'}))
    survey_database = forms.CharField(required=True, widget=forms.TextInput(attrs={'size':'20'}))


def eventList(request):
    from django.db import connection
    queryset = Events.objects.all().order_by('id')

    if request.method == 'POST':
        form = AddEventForm(request.POST)
        if form.is_valid(): # All validation rules pass

            ra = form.cleaned_data['ra']
            decl = form.cleaned_data['decl']
            flagDate = form.cleaned_data['flagDate']
            userId = form.cleaned_data['userId']
            internalObjectId = form.cleaned_data['internalObjectId']
            internalName = form.cleaned_data['internalName']
            survey_database = form.cleaned_data['survey_database']
            htm16id = htmID(16,ra,decl)

            if not flagDate:
                flagDate = datetime.now()

            year = flagDate.year
            print(year)

            # Is there an object within RADIUS arcsec of this object?
            message, results = coneSearchHTM(ra, decl, RADIUS, 'events', queryType = FULL, conn = connection, django = True)

            # So - if there are NO matches, insert into the relevant year based
            # on either the flag date OR choose from the current year.
            # But if there ARE matches, shove into the AKAs table with the RA and
            # dec.  We may use this later to recalculate the RA and Dec in the
            # events table.
            if len(results) > 0:
                event = Struct(**results[0][1])
                separation = results[0][0]

                try:
                    aka = Akas(ra = ra,
                               decl = decl,
                               event_id_id = event.id,
                               object_id = internalObjectId,
                               aka = internalName,
                               survey_database = survey_database,
                               user_id = userId,
                               source_ip = None,
                               htm16id = htm16id)  # Field name made lowercase.
                    aka.save()
                except IntegrityError as e:
                    #print(e[0])
                    #if e[0] == 1062: # Duplicate Key error
                    pass # Do nothing - will eventually raise some errors on the form

            else:
                y = years[year](ra = ra,
                                decl = decl,
                                object_id = internalObjectId,
                                survey_database = survey_database,
                                user_id = userId,
                                source_ip = None,
                                htm16id = htm16id)  # Field name made lowercase.
                y.save()
                print(y)

                acquiredId = y.pk
                print(acquiredId)
                suffix = base26(acquiredId - (MULTIPLIER * (year - 2000)))
                print(suffix)
                event = Events(id = acquiredId,
                               ra = ra,
                               decl = decl,
                               ra_original = ra,
                               decl_original = decl,
                               year = year,
                               base26suffix = suffix,
                               htm16id = htm16id)  # Field name made lowercase.

                           #survey_database = survey_database,
                event.save()

                # Add the aka
                aka = Akas(ra = ra,
                           decl = decl,
                           event_id_id = acquiredId,
                           object_id = internalObjectId,
                           aka = internalName,
                           survey_database = survey_database,
                           user_id = userId,
                           source_ip = None,
                           htm16id = htm16id)  # Field name made lowercase.
                aka.save()


    else:
        form = AddEventForm()

    table = EventsTable(queryset, order_by=request.GET.get('sort', '-id'))
    RequestConfig(request, paginate={"per_page": 100}).configure(table)
    return render(request, 'events.html', {'table': table, 'form' : form})




from django.shortcuts import get_object_or_404, render

# Create your views here.
# views.py
from rest_framework import viewsets
from rest_framework.response import Response
from rest_framework.decorators import api_view
from rest_framework.views import APIView
from nameserver.models import Events
from rest_framework import status
from .serializers import EventsSerializer, EventSerializer
from rest_framework.authentication import TokenAuthentication
from rest_framework.permissions import IsAuthenticated
from rest_framework import mixins, viewsets

class EventsViewSet(viewsets.ModelViewSet):
    queryset = Events.objects.all().order_by('id')
    serializer_class = EventsSerializer


# The inputs to the following class apparently replace APIView
#class EventView(mixins.ListModelMixin, viewsets.GenericViewSet):
class EventView(APIView):
    authentication_classes = [TokenAuthentication]
    permission_classes = [IsAuthenticated]

    def get(self, request):
        #events = Events.objects.all()
        #serializer = EventSerializer(events, many=True)
        return Response({"Error": "GET is not implemented for this service."})

    def post(self, request, format=None):
        serializer = EventSerializer(data=request.data, context={'request': request})
        if serializer.is_valid():
            message = serializer.save()
            #return Response(serializer.data, status=status.HTTP_201_CREATED)
            return Response(message, status=status.HTTP_201_CREATED)
        return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)




# serializers.py
from rest_framework import serializers
from nameserver.models import *
from nameserver.views import years
from gkhtm._gkhtm import htmID
from gkutils.commonutils import coneSearchHTM, FULL, CAT_ID_RA_DEC_COLS, base26, Struct
from datetime import datetime
from django.db import connection
from django.db import IntegrityError
import re

RADIUS = 3.0 # arcsec
MULTIPLIER = 10000000

# I can't believe that this works! The events table is not part of my long list,
# but we can add it here.
CAT_ID_RA_DEC_COLS['events'] = [['id', 'ra', 'decl'],1017]

# If we get an internal ATLAS name, we'd like to pull it apart and compare the year
# with the flag date.  If the year is different form the flag date, use the name
# year. Otherwise we will create the wrong internal name!

NAME_REGEX = "^ATLAS([0-9][0-9])([a-z]{1,4})$"
NAME_REGEX_COMPILED = re.compile(NAME_REGEX)

# Return all the events
class EventsSerializer(serializers.ModelSerializer):
    class Meta:
        model = Events
        fields = ('id', 'ra', 'decl', 'ra_original', 'decl_original', 'date_inserted', 'date_updated', 'year', 'base26suffix')
        #fields = '__all__'


# Receive and add a new event
# Counter is optional - it should only be provided as part of the ingest
# process for existing data.
class EventSerializer(serializers.Serializer):
    internalObjectId = serializers.IntegerField(required=True)
    internalName = serializers.CharField(max_length=20)
    ra = serializers.FloatField(required=True)
    decl = serializers.FloatField(required=True)
    flagDate = serializers.DateField(required=False, default=datetime.now())
    counter = serializers.IntegerField(required=False, default=0)
    survey_database = serializers.CharField(required=True, max_length=20)


    def save(self):

        from django.conf import settings
        ra = self.validated_data['ra']
        decl = self.validated_data['decl']
        internalObjectId = self.validated_data['internalObjectId']
        internalName = self.validated_data['internalName']
        survey_database = self.validated_data['survey_database']

        nameYear = None
        if internalName is not None:
            namecut = NAME_REGEX_COMPILED.search(internalName)
            if namecut is not None and namecut.group(1) is not None:
                nameYear = 2000 + int(namecut.group(1))

        # Get the authenticated user, if it exists.
        userId = 'unknown'
        request = self.context.get("request")
        if request and hasattr(request, "user"):
            userId = str(request.user)

        print ("EXTRACTED USER ID = ", userId)
        htm16id = htmID(16, ra, decl)

        flagDate = self.validated_data['flagDate']
        #if not flagDate:
        #    flagDate = datetime.now()

        year = flagDate.year

        # Sometimes the year in the name does NOT correspond to the flag date.  This is
        # especially true for objects flagged in the atlas4 database that were originally
        # discovered in atlas3.

        if nameYear is not None and nameYear != year:
            year = nameYear

        acquiredId = 0

        counter = self.validated_data['counter']
        if counter is not None and counter > 0:
            acquiredId = (year - 2000) * MULTIPLIER + counter

        if not flagDate:
            flagDate = datetime.now()

        replyMessage = 'Object created'

        # Is there an object within RADIUS arcsec of this object?
        message, results = coneSearchHTM(ra, decl, RADIUS, 'events', queryType = FULL, conn = connection, django = True)

        # So - if there are NO matches, insert into the relevant year based
        # on either the flag date OR choose from the current year.
        # But if there ARE matches, shove into the AKAs table with the RA and
        # dec.  We may use this later to recalculate the RA and Dec in the
        # events table.
        if len(results) > 0:
            event = Struct(**results[0][1])
            separation = results[0][0]
            replyMessage = 'Object already exists'

            try:
                aka = Akas(ra = ra,
                           decl = decl,
                           event_id_id = event.id,
                           object_id = internalObjectId,
                           aka = internalName,
                           survey_database = survey_database,
                           user_id = userId,
                           source_ip = None,
                           original_flag_date = flagDate,
                           htm16id = htm16id)
                #aka.save()
                aka.save(force_insert=True)
            except IntegrityError as e:
                #print(e[0])
                #if e[0] == 1062: # Duplicate Key error
                replyMessage = 'Duplicate AKA - cannot add AKA'

        else:
            if acquiredId != 0:
                y = years[year](id = acquiredId,
                                ra = ra,
                                decl = decl,
                                object_id = internalObjectId,
                                survey_database = survey_database,
                                user_id = userId,
                                source_ip = None,
                                htm16id = htm16id)
            else:
                y = years[year](ra = ra,
                                decl = decl,
                                object_id = internalObjectId,
                                survey_database = survey_database,
                                user_id = userId,
                                source_ip = None,
                                htm16id = htm16id)
            try:
                #y.save()
                y.save(force_insert=True)
            except IntegrityError as e:
                #print(e[0])
                #if e[0] == 1062: # Duplicate Key error
                replyMessage = 'Duplicate Year Entry - cannot create year entry'

            acquiredId = y.pk
            suffix = base26(acquiredId - (MULTIPLIER * (year - 2000)))
            try:
                event = Events(id = acquiredId,
                               ra = ra,
                               decl = decl,
                               ra_original = ra,
                               decl_original = decl,
                               year = year,
                               base26suffix = suffix,
                               htm16id = htm16id)

                #event.save()
                event.save(force_insert=True)
            except IntegrityError as e:
                #print(e[0])
                #if e[0] == 1062: # Duplicate Key error
                replyMessage = 'Duplicate AKA - cannot add new AKA'

            # Add the aka
            try:
                aka = Akas(ra = ra,
                           decl = decl,
                           event_id_id = acquiredId,
                           object_id = internalObjectId,
                           aka = internalName,
                           survey_database = survey_database,
                           user_id = userId,
                           source_ip = None,
                           original_flag_date = flagDate,
                           htm16id = htm16id)
                #aka.save()
                aka.save(force_insert=True)
            except IntegrityError as e:
                #print(e[0])
                #if e[0] == 1062: # Duplicate Key error
                replyMessage = 'Duplicate AKA - cannot add new AKA'

        objectName = settings.OBJECT_PREFIX + "%d" % (year - 2000) + event.base26suffix
        #return event

        info = { "event_id": objectName, "info": replyMessage }
        return info




# Generated by Django 3.0.7 on 2020-06-23 22:18

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Akas',
            fields=[
                ('id', models.PositiveIntegerField(primary_key=True, serialize=False)),
                ('object_id', models.BigIntegerField()),
                ('aka', models.CharField(blank=True, max_length=30, null=True)),
                ('ra', models.FloatField()),
                ('decl', models.FloatField()),
                ('survey_database', models.CharField(max_length=50)),
                ('user_id', models.CharField(max_length=50)),
                ('source_ip', models.CharField(blank=True, max_length=20, null=True)),
                ('date_inserted', models.DateTimeField()),
                ('htm16id', models.BigIntegerField(db_column='htm16ID')),
            ],
            options={
                'db_table': 'akas',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Events',
            fields=[
                ('id', models.PositiveIntegerField(primary_key=True, serialize=False)),
                ('ra', models.FloatField()),
                ('decl', models.FloatField()),
                ('ra_original', models.FloatField()),
                ('decl_original', models.FloatField()),
                ('date_inserted', models.DateTimeField()),
                ('date_updated', models.DateTimeField(blank=True, null=True)),
                ('year', models.PositiveSmallIntegerField()),
                ('base26suffix', models.CharField(max_length=20)),
                ('htm16id', models.BigIntegerField(db_column='htm16ID')),
            ],
            options={
                'db_table': 'events',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Y2016',
            fields=[
                ('id', models.PositiveIntegerField(primary_key=True, serialize=False)),
                ('object_id', models.BigIntegerField()),
                ('ra', models.FloatField()),
                ('decl', models.FloatField()),
                ('survey_database', models.CharField(max_length=50)),
                ('user_id', models.CharField(max_length=50)),
                ('source_ip', models.CharField(blank=True, max_length=20, null=True)),
                ('date_inserted', models.DateTimeField()),
                ('htm16id', models.BigIntegerField(db_column='htm16ID')),
            ],
            options={
                'db_table': 'y2016',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Y2017',
            fields=[
                ('id', models.PositiveIntegerField(primary_key=True, serialize=False)),
                ('object_id', models.BigIntegerField()),
                ('ra', models.FloatField()),
                ('decl', models.FloatField()),
                ('survey_database', models.CharField(max_length=50)),
                ('user_id', models.CharField(max_length=50)),
                ('source_ip', models.CharField(blank=True, max_length=20, null=True)),
                ('date_inserted', models.DateTimeField()),
                ('htm16id', models.BigIntegerField(db_column='htm16ID')),
            ],
            options={
                'db_table': 'y2017',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Y2018',
            fields=[
                ('id', models.PositiveIntegerField(primary_key=True, serialize=False)),
                ('object_id', models.BigIntegerField()),
                ('ra', models.FloatField()),
                ('decl', models.FloatField()),
                ('survey_database', models.CharField(max_length=50)),
                ('user_id', models.CharField(max_length=50)),
                ('source_ip', models.CharField(blank=True, max_length=20, null=True)),
                ('date_inserted', models.DateTimeField()),
                ('htm16id', models.BigIntegerField(db_column='htm16ID')),
            ],
            options={
                'db_table': 'y2018',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Y2019',
            fields=[
                ('id', models.PositiveIntegerField(primary_key=True, serialize=False)),
                ('object_id', models.BigIntegerField()),
                ('ra', models.FloatField()),
                ('decl', models.FloatField()),
                ('survey_database', models.CharField(max_length=50)),
                ('user_id', models.CharField(max_length=50)),
                ('source_ip', models.CharField(blank=True, max_length=20, null=True)),
                ('date_inserted', models.DateTimeField()),
                ('htm16id', models.BigIntegerField(db_column='htm16ID')),
            ],
            options={
                'db_table': 'y2019',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Y2020',
            fields=[
                ('id', models.PositiveIntegerField(primary_key=True, serialize=False)),
                ('object_id', models.BigIntegerField()),
                ('ra', models.FloatField()),
                ('decl', models.FloatField()),
                ('survey_database', models.CharField(max_length=50)),
                ('user_id', models.CharField(max_length=50)),
                ('source_ip', models.CharField(blank=True, max_length=20, null=True)),
                ('date_inserted', models.DateTimeField()),
                ('htm16id', models.BigIntegerField(db_column='htm16ID')),
            ],
            options={
                'db_table': 'y2020',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Y2021',
            fields=[
                ('id', models.PositiveIntegerField(primary_key=True, serialize=False)),
                ('object_id', models.BigIntegerField()),
                ('ra', models.FloatField()),
                ('decl', models.FloatField()),
                ('survey_database', models.CharField(max_length=50)),
                ('user_id', models.CharField(max_length=50)),
                ('source_ip', models.CharField(blank=True, max_length=20, null=True)),
                ('date_inserted', models.DateTimeField()),
                ('htm16id', models.BigIntegerField(db_column='htm16ID')),
            ],
            options={
                'db_table': 'y2021',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Y2022',
            fields=[
                ('id', models.PositiveIntegerField(primary_key=True, serialize=False)),
                ('object_id', models.BigIntegerField()),
                ('ra', models.FloatField()),
                ('decl', models.FloatField()),
                ('survey_database', models.CharField(max_length=50)),
                ('user_id', models.CharField(max_length=50)),
                ('source_ip', models.CharField(blank=True, max_length=20, null=True)),
                ('date_inserted', models.DateTimeField()),
                ('htm16id', models.BigIntegerField(db_column='htm16ID')),
            ],
            options={
                'db_table': 'y2022',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Y2023',
            fields=[
                ('id', models.PositiveIntegerField(primary_key=True, serialize=False)),
                ('object_id', models.BigIntegerField()),
                ('ra', models.FloatField()),
                ('decl', models.FloatField()),
                ('survey_database', models.CharField(max_length=50)),
                ('user_id', models.CharField(max_length=50)),
                ('source_ip', models.CharField(blank=True, max_length=20, null=True)),
                ('date_inserted', models.DateTimeField()),
                ('htm16id', models.BigIntegerField(db_column='htm16ID')),
            ],
            options={
                'db_table': 'y2023',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Y2024',
            fields=[
                ('id', models.PositiveIntegerField(primary_key=True, serialize=False)),
                ('object_id', models.BigIntegerField()),
                ('ra', models.FloatField()),
                ('decl', models.FloatField()),
                ('survey_database', models.CharField(max_length=50)),
                ('user_id', models.CharField(max_length=50)),
                ('source_ip', models.CharField(blank=True, max_length=20, null=True)),
                ('date_inserted', models.DateTimeField()),
                ('htm16id', models.BigIntegerField(db_column='htm16ID')),
            ],
            options={
                'db_table': 'y2024',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Y2025',
            fields=[
                ('id', models.PositiveIntegerField(primary_key=True, serialize=False)),
                ('object_id', models.BigIntegerField()),
                ('ra', models.FloatField()),
                ('decl', models.FloatField()),
                ('survey_database', models.CharField(max_length=50)),
                ('user_id', models.CharField(max_length=50)),
                ('source_ip', models.CharField(blank=True, max_length=20, null=True)),
                ('date_inserted', models.DateTimeField()),
                ('htm16id', models.BigIntegerField(db_column='htm16ID')),
            ],
            options={
                'db_table': 'y2025',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Y2026',
            fields=[
                ('id', models.PositiveIntegerField(primary_key=True, serialize=False)),
                ('object_id', models.BigIntegerField()),
                ('ra', models.FloatField()),
                ('decl', models.FloatField()),
                ('survey_database', models.CharField(max_length=50)),
                ('user_id', models.CharField(max_length=50)),
                ('source_ip', models.CharField(blank=True, max_length=20, null=True)),
                ('date_inserted', models.DateTimeField()),
                ('htm16id', models.BigIntegerField(db_column='htm16ID')),
            ],
            options={
                'db_table': 'y2026',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Y2027',
            fields=[
                ('id', models.PositiveIntegerField(primary_key=True, serialize=False)),
                ('object_id', models.BigIntegerField()),
                ('ra', models.FloatField()),
                ('decl', models.FloatField()),
                ('survey_database', models.CharField(max_length=50)),
                ('user_id', models.CharField(max_length=50)),
                ('source_ip', models.CharField(blank=True, max_length=20, null=True)),
                ('date_inserted', models.DateTimeField()),
                ('htm16id', models.BigIntegerField(db_column='htm16ID')),
            ],
            options={
                'db_table': 'y2027',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Y2028',
            fields=[
                ('id', models.PositiveIntegerField(primary_key=True, serialize=False)),
                ('object_id', models.BigIntegerField()),
                ('ra', models.FloatField()),
                ('decl', models.FloatField()),
                ('survey_database', models.CharField(max_length=50)),
                ('user_id', models.CharField(max_length=50)),
                ('source_ip', models.CharField(blank=True, max_length=20, null=True)),
                ('date_inserted', models.DateTimeField()),
                ('htm16id', models.BigIntegerField(db_column='htm16ID')),
            ],
            options={
                'db_table': 'y2028',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Y2029',
            fields=[
                ('id', models.PositiveIntegerField(primary_key=True, serialize=False)),
                ('object_id', models.BigIntegerField()),
                ('ra', models.FloatField()),
                ('decl', models.FloatField()),
                ('survey_database', models.CharField(max_length=50)),
                ('user_id', models.CharField(max_length=50)),
                ('source_ip', models.CharField(blank=True, max_length=20, null=True)),
                ('date_inserted', models.DateTimeField()),
                ('htm16id', models.BigIntegerField(db_column='htm16ID')),
            ],
            options={
                'db_table': 'y2029',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Y2030',
            fields=[
                ('id', models.PositiveIntegerField(primary_key=True, serialize=False)),
                ('object_id', models.BigIntegerField()),
                ('ra', models.FloatField()),
                ('decl', models.FloatField()),
                ('survey_database', models.CharField(max_length=50)),
                ('user_id', models.CharField(max_length=50)),
                ('source_ip', models.CharField(blank=True, max_length=20, null=True)),
                ('date_inserted', models.DateTimeField()),
                ('htm16id', models.BigIntegerField(db_column='htm16ID')),
            ],
            options={
                'db_table': 'y2030',
                'managed': False,
            },
        ),
    ]



"""
Django settings for nameserver project.

Generated by 'django-admin startproject' using Django 3.0.7.

For more information on this file, see
https://docs.djangoproject.com/en/3.0/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/3.0/ref/settings/
"""

import os
from dotenv import load_dotenv

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
PATHPREFIX = os.environ.get('WSGI_PREFIX')
SECRET_KEY = os.environ.get('DJANGO_SECRET_KEY')

# Set the prefix for the object id you want to return to the requester.
OBJECT_PREFIX = os.environ.get('DJANGO_OBJECT_PREFIX')

SITE_ID = 1
# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/3.0/howto/deployment/checklist/


# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = True

ALLOWED_HOSTS = []

# Set cookie names for session authentication
CSRF_COOKIE_NAME = 'csrf_' + os.environ.get('DJANGO_MYSQL_DBNAME')
SESSION_COOKIE_NAME = 'session_' + os.environ.get('DJANGO_MYSQL_DBNAME')

# Application definition

INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.messages',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.staticfiles',
    'rest_framework',
    'rest_framework.authtoken',
    'django_tables2',
    'nameserver',
    'nameserverapi.apps.NameserverapiConfig',
]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

# Added token authentication class
REST_FRAMEWORK = {
    'DEFAULT_AUTHENTICATION_CLASSES': [
        'rest_framework.authentication.TokenAuthentication',
    ]
}

ROOT_URLCONF = 'nameserver.urls'

# List of callables that know how to import templates from various sources.
TEMPLATE_LOADERS = (
    'django.template.loaders.filesystem.Loader',
    'django.template.loaders.app_directories.Loader',
)

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [
            # insert your TEMPLATE_DIRS here
            os.path.join(BASE_DIR, 'nameserver/templates'),

        ],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                # Insert your TEMPLATE_CONTEXT_PROCESSORS here or use this
                # list if you haven't customized them:
                "django.contrib.auth.context_processors.auth",
                "django.contrib.messages.context_processors.messages",
                "django.template.context_processors.debug",
                "django.template.context_processors.i18n",
                "django.template.context_processors.media",
                "django.template.context_processors.request",
                "django.template.context_processors.static",
            ],
        },
    },
]

WSGI_APPLICATION = 'nameserver.wsgi.application'

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.mysql',
        'NAME': os.environ.get('DJANGO_MYSQL_DBNAME'),
        'USER': os.environ.get('DJANGO_MYSQL_DBUSER'),
        'PASSWORD': os.environ.get('DJANGO_MYSQL_DBPASS'),
        'HOST': os.environ.get('DJANGO_MYSQL_DBHOST'),
        'PORT': int(os.environ.get('DJANGO_MYSQL_DBPORT')),
    }
}

# Internationalization
# https://docs.djangoproject.com/en/3.0/topics/i18n/

LANGUAGE_CODE = 'en-gb'

TIME_ZONE = 'UTC'

USE_I18N = True

USE_L10N = True

USE_TZ = True

# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/3.0/howto/static-files/

STATIC_URL = PATHPREFIX + '/static/'

# STATICFILES_DIRS tells collectstatic where MY static files are.
STATICFILES_DIRS = (
  os.path.join(BASE_DIR, 'staticfiles'),
)

STATIC_ROOT = os.path.join(BASE_DIR, 'static')

